import { defineMiddleware } from "astro/middleware"
import ResponseBuilder from 'libs/ResponseBuilder'

// `context` and `next` are automatically typed
export default defineMiddleware(async ({ request }, next) => {
	const prefix = `[${new Date().toISOString()}] ${request.headers.get('user-agent')?.slice(0, 32).padEnd(32)} ${request.method.padEnd(7)}`
	console.log(`${prefix} ${request.url}`)

	// can crash if response crash
	try {
		const res = await next()

		console.log(`${prefix} ${res.status} ${request.url}`)

		return res
	} catch (e) {
		console.log(`${prefix} 500 ${request.url}`)
		console.error('-------------------------------')
		console.error(e)
		console.error('-------------------------------')

		return new ResponseBuilder()
			.status(500)
			.body('An error occured while processing your request')
			.build()
	}
})
